@@ -18,7 +18,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>
  *
  */
 
@@ -448,6 +448,9 @@ encrypt_packet_tls13(gnutls_session_t session,
 		return plain->size;
 	}
 
+	if (unlikely(iv_size < 8))
+		return gnutls_assert_val(GNUTLS_E_INTERNAL_ERROR);
+
 	memcpy(nonce, params->write.iv, iv_size);
 	memxor(&nonce[iv_size-8], UINT64DATA(params->write.sequence_number), 8);
 
@@ -869,6 +872,15 @@ decrypt_packet_tls13(gnutls_session_t session,
 	if (unlikely(ret < 0))
 		return gnutls_assert_val(ret);
 
+	/* 1 octet for content type */
+	if (length > max_decrypted_size(session) + 1) {
+		_gnutls_audit_log
+		    (session, "Received packet with illegal length: %u\n",
+		     (unsigned int) length);
+
+		return gnutls_assert_val(GNUTLS_E_RECORD_OVERFLOW);
+	}
+
 	length_set = 0;
 
 	/* now figure the actual data size. We intentionally iterate through all data,
